<?php

declare(strict_types=1);

use Hyperf\ModelCache\Handler\RedisHandler;

return [
    'default' => [
        'driver' => env('DB_DRIVER', 'mysql'),
        'write' => [
            'host' => explode(',', (string) env('DB_MASTER_HOST')),
            'port' => env('DB_MASTER_PORT', 13306),
        ],
        'read' => [
            'host' => explode(',', (string) env('DB_SLAVE_HOST')),
            'port' => env('DB_SLAVE_PORT', 13306),
        ],
        'sticky' => true,
        'database' => env('DB_DATABASE', 'hyperf'),
        'username' => env('DB_USERNAME', 'root'),
        'password' => env('DB_PASSWORD', ''),
        'charset' => env('DB_CHARSET', 'utf8mb4'),
        'collation' => env('DB_COLLATION', 'utf8mb4_unicode_ci'),
        'prefix' => env('DB_PREFIX', ''),
        'pool' => [
            'min_connections' => 1,
            'max_connections' => 10,
            'connect_timeout' => 10.0,
            'wait_timeout' => 3.0,
            'heartbeat' => -1,
            'max_idle_time' => (float) env('DB_MAX_IDLE_TIME', 60),
        ],
        'cache' => [
            'handler' => RedisHandler::class,
            'cache_key' => 'mc:%s:m:%s:%s:%s',
            'prefix' => 'default',
            'ttl' => 3600 * 24,
            'empty_model_ttl' => 3600,
            'load_script' => true,
            'use_default_value' => false,
        ],
        'commands' => [
            'gen:model' => [
                'path' => 'app/Model',
                'force_casts' => true,
                'inheritance' => 'Model',
                'uses' => 'App\Model\Model',
            ],
        ],
    ],
];
